scipy.odr.ODR
=============

.. currentmodule:: scipy.odr

.. autoclass:: ODR

   

   .. HACK
      .. autosummary::
         :toctree:
      
         ODR.__init__
         ODR.restart
         ODR.run
         ODR.set_iprint
         ODR.set_job



   

